{% extends "base.html" %}
{% load staticfiles %}

{% block extra_css %}
<link rel="stylesheet" href="{% static "css/detail.css" %}">
{% endblock %}

{% block sidebar %}
{% include "sidebar.html" with active="apps" %}
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
  <a href="{% url 'list-app' %}">apps</a> <span class="arrow">></span>
  {{ app.name }}
</div>
{% endblock %}

{% block header %}
<h1>{{ app.name }}</h1>
- <a href="http://{{ app.ip }}" target="_blank">http://{{ app.ip }}</a>
{% endblock %}

{% block content %}
<div class="container-fluid">
  {% block navbar %}
  {% include "apps/navbar.html" with active="resources" %}
  {% endblock %}
  {% block app-content %}{% endblock %}
</div>
{% endblock content %}
