.apply-btn {
	display: none;
	margin: 41px 0 0 0;
}

#h-slider {
	width: 300px;
	margin: 46px 0 0 0;
}

.units-box {
	height: 95px;
}

.stats {
	width: 80px;
	max-height: 80px;
	display: inline-block;
	padding: 12px 0;
	margin: 8px 5px 1em;
	vertical-align: top;
	text-decoration: none;
	background: #F3F3F3;
	background-color: #f8f8f8;
	background-image: -moz-linear-gradient(top, #ffffff, #eeeeee);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#eeeeee));
	background-image: -webkit-linear-gradient(top, #ffffff, #eeeeee);
	background-image: linear-gradient(to bottom, #ffffff, #eeeeee);
	border: 1px solid #ddd;
	box-sizing: border-box;
	border-radius: 5px;
	text-align: center;
}

.stats strong {
	font-weight: bold;
	font-size: 40px;
	display: block;
	padding: 10px 0;
}

.hide {
    display: none;
}

h1 {
    display: inline-block;
}
